#

##

##

###

##

##

##

##

    	IPTables

    	list rules
    		ip6tables -L
    		iptables -L

    	block
    		outgoing
    			iptables -P OUTPUT DROP

    			#
    			#	allow one user
    			#
    			useradd -m -s /bin/bash communicator
    			passwd communicator # EEC1234

    			iptables -A OUTPUT -m owner --uid-owner communicator -j ACCEPT

    			sudo -u communicator firefox

    			#
    			#	???
    			#
    			iptables -P INPUT DROP
    			iptables -A INPUT -m owner --uid-owner communicator -j ACCEPT
    			iptables -A INPUT -m owner --uid-owner communicator -j ACCEPT

    			iptables -P FORWARD DROP

    	delete

    		a chain rule by number:
    			iptables -L -n --line-numbers
    			iptables -D INPUT 1

    			iptables -D FORWARD 7

    	flush
    		a chain:
    			iptables -F

    	save?
    		mkdir -p  /etc/iptables
    		iptables-save > /etc/iptables/rules.v4
    		ip6tables-save > /etc/iptables/rules.v6

    		# iptables-legacy-save

    	chains